@@ -183,9 +183,13 @@ class Flexi:
                         exchanged_dictionary.update({key_list:exchanged_dictionary.get(key_list[0])})
                         index_list = [new_object.d_index(keys) for keys in key_list]
                 if return_type == "no_update":
+                    new_exchanged_dictionary = {}
                     if len(index_list)!=0:
                         new_exchanged_dictionary = new_object.d_remove(index_list,return_type="no_update")
-                    return {value: key for key,value in new_exchanged_dictionary.items()}
+                        return {value: key for key,value in new_exchanged_dictionary.items()}
+                    else:
+                        return {value: key for key,value in exchanged_dictionary.items()}
+
                 
                 elif return_type == "update":
                     if len(index_list)!=0:
@@ -199,7 +203,6 @@ class Flexi:
             if return_type == "no_update":
                 return self.dictionary
 
-
     def d_reverse(self, no_of_times=1, return_type="no_update"):
         """
         It reverses the dictionary and returns the reversed dictionary. 
@@ -395,13 +398,12 @@ class Flexi:
         if return_type not in ["no_update", "update"]:
             raise Exception("return_type should be either update or no_update")
 
-        exchanged_list = [[key, value]
-                          for key, value in list(self.dictionary.items())]
-        exchanged_list[initial_index][0], exchanged_list[final_index][0] = exchanged_list[initial_index][0], exchanged_list[final_index][0]
-        exchanged_dictionary = dict(exchanged_list)
+        exchanged_list = [[key, value]for key, value in list(self.dictionary.items())]
+        exchanged_list[initial_index][0], exchanged_list[final_index][0] = exchanged_list[final_index][0], exchanged_list[initial_index][0]
 
+        exchanged_dictionary = dict(exchanged_list)
         if return_type == "no_update":
-            return exchanged_dictionary
+            return  exchanged_dictionary
         else:
             self.dictionary.clear()
             self.dictionary.update(exchanged_dictionary)
@@ -425,7 +427,7 @@ class Flexi:
 
         exchanged_list = [[key, value]
                           for key, value in list(self.dictionary.items())]
-        exchanged_list[initial_index][1], exchanged_list[final_index][1] = exchanged_list[initial_index][1], exchanged_list[final_index][1]
+        exchanged_list[initial_index][1], exchanged_list[final_index][1] = exchanged_list[final_index][1], exchanged_list[initial_index][1]
         exchanged_dictionary = dict(exchanged_list)
 
         if return_type == "no_update":
@@ -696,4 +698,3 @@ class Flexi:
 
 
 
-
